# squares
Squares is an identicon generator. For more information, check out [its PyPI page](https://pypi.org/project/squares).

## Examples
<p align="center">
  <img src="examples/deukn.png?raw=true" width="128"/>&nbsp;&nbsp;
  <img src="examples/eynqv.png?raw=true" width="128"/>&nbsp;&nbsp;
  <img src="examples/pcmfd.png?raw=true" width="128"/>&nbsp;&nbsp;
  <img src="examples/rcvyd.png?raw=true" width="128"/>&nbsp;&nbsp;
  <img src="examples/zkmmu.png?raw=true" width="128"/>
</p>
